@@ -28,49 +28,12 @@
 
 #include <clutter-gst/clutter-gst.h>
 
-void
-size_change (ClutterTexture *texture,
-             gint            width,
-             gint            height,
-             gpointer        user_data)
-{
-  ClutterActor *stage;
-  gfloat new_x, new_y, new_width, new_height;
-  gfloat stage_width, stage_height;
-
-  stage = clutter_actor_get_stage (CLUTTER_ACTOR (texture));
-  if (stage == NULL)
-    return;
-
-  clutter_actor_get_size (stage, &stage_width, &stage_height);
-
-  new_height = (height * stage_width) / width;
-  if (new_height <= stage_height)
-    {
-      new_width = stage_width;
-
-      new_x = 0;
-      new_y = (stage_height - new_height) / 2;
-    }
-  else
-    {
-      new_width  = (width * stage_height) / height;
-      new_height = stage_height;
-
-      new_x = (stage_width - new_width) / 2;
-      new_y = 0;
-    }
-
-  clutter_actor_set_position (CLUTTER_ACTOR (texture), new_x, new_y);
-  clutter_actor_set_size (CLUTTER_ACTOR (texture), new_width, new_height);
-}
-
 int
 main (int argc, char *argv[])
 {
   ClutterTimeline  *timeline;
   ClutterActor     *stage;
-  ClutterActor     *texture;
+  ClutterActor     *actor;
   ClutterConstraint *constraint;
   GstPipeline      *pipeline;
   GstElement       *src;
@@ -99,16 +62,9 @@ main (int argc, char *argv[])
   timeline = clutter_timeline_new (1000);
   g_object_set(timeline, "loop", TRUE, NULL);
 
-  /* We need to set certain props on the target texture currently for
-   * efficient/corrent playback onto the texture (which sucks a bit)
-  */
-  texture = g_object_new (CLUTTER_TYPE_TEXTURE,
-			  "disable-slicing", TRUE,
-			  NULL);
-
-  g_signal_connect (CLUTTER_TEXTURE (texture),
-		    "size-change",
-		    G_CALLBACK (size_change), NULL);
+  actor = g_object_new (CLUTTER_TYPE_ACTOR,
+                        "content", clutter_gst_content_new (),
+                        NULL);
 
   /* Set up pipeline */
   pipeline = GST_PIPELINE(gst_pipeline_new (NULL));
@@ -118,27 +74,30 @@ main (int argc, char *argv[])
 
   test = gst_element_factory_make ("navigationtest", NULL);
   colorspace = gst_element_factory_make ("videoconvert", NULL);
-  sink = gst_element_factory_make ("cluttersink", NULL);
-  g_object_set (sink, "texture", CLUTTER_TEXTURE (texture), NULL);
+
+  sink = gst_element_factory_make ("clutterautovideosink", NULL);
+  g_object_set (sink, "content", clutter_actor_get_content (actor), NULL);
 
   // g_object_set (src , "pattern", 10, NULL);
 
   gst_bin_add_many (GST_BIN (pipeline), src, filter, test, colorspace, sink, NULL);
-  gst_element_link_many (src, filter, test, colorspace, sink, NULL);
+  gst_element_link_many (src, filter, test, colorspace,
+                         GST_ELEMENT (clutter_gst_content_get_sink (CLUTTER_GST_CONTENT (clutter_actor_get_content (actor)))),
+                         NULL);
   gst_element_set_state (GST_ELEMENT(pipeline), GST_STATE_PLAYING);
 
   /* Resize with the window */
   constraint = clutter_bind_constraint_new (stage, CLUTTER_BIND_SIZE, 0.0);
-  clutter_actor_add_constraint_with_name (texture, "size", constraint);
+  clutter_actor_add_constraint_with_name (actor, "size", constraint);
 
   /* Rotate a bit */
-  clutter_actor_set_pivot_point (texture, 0.5, 0.5);
-  clutter_actor_set_rotation_angle (texture, CLUTTER_Z_AXIS, 45.0);
+  clutter_actor_set_pivot_point (actor, 0.5, 0.5);
+  clutter_actor_set_rotation_angle (actor, CLUTTER_Z_AXIS, 45.0);
 
   /* start the timeline */
   clutter_timeline_start (timeline);
 
-  clutter_actor_add_child (stage, texture);
+  clutter_actor_add_child (stage, actor);
   // clutter_actor_set_opacity (texture, 0x11);
   clutter_actor_show (stage);
 
