@@ -33,40 +33,7 @@
 char *video_files[] = {NULL, NULL};
 
 void
-size_change (ClutterTexture *texture,
-             gint            width,
-             gint            height,
-             gpointer        user_data)
-{
-  ClutterActor *stage = (ClutterActor *)user_data;
-  gfloat new_x, new_y, new_width, new_height;
-  gfloat stage_width, stage_height;
-
-  clutter_actor_get_size (stage, &stage_width, &stage_height);
-
-  new_height = (height * stage_width) / width;
-  if (new_height <= stage_height)
-    {
-      new_width = stage_width;
-
-      new_x = 0;
-      new_y = (stage_height - new_height) / 2;
-    }
-  else
-    {
-      new_width  = (width * stage_height) / height;
-      new_height = stage_height;
-
-      new_x = (stage_width - new_width) / 2;
-      new_y = 0;
-    }
-
-  clutter_actor_set_position (CLUTTER_ACTOR (texture), new_x, new_y);
-  clutter_actor_set_size (CLUTTER_ACTOR (texture), new_width, new_height);
-}
-
-void
-on_error (ClutterMedia *media)
+on_error (ClutterGstPlayer *player)
 {
   g_print ("error\n");
   clutter_main_quit ();
@@ -76,17 +43,17 @@ gboolean
 test (gpointer data)
 {
   static int count = 1;
-  static ClutterMedia *media = NULL;
+  static ClutterGstPlayback *player = NULL;
   static char *uri[2] = {NULL, NULL};
   const char *playing_uri = NULL;
 
   /* Check until we get video playing */
-  if (!clutter_media_get_playing (CLUTTER_MEDIA (data)))
+  if (!clutter_gst_player_get_playing (CLUTTER_GST_PLAYER (data)))
     return TRUE;
 
-  if (CLUTTER_MEDIA (data) != media)
+  if (CLUTTER_GST_PLAYBACK (data) != player)
     {
-      media = CLUTTER_MEDIA (data);
+      player = CLUTTER_GST_PLAYBACK (data);
       count = 1;
       g_free(uri[0]);
       uri[0] = NULL;
@@ -94,25 +61,25 @@ test (gpointer data)
       uri[1] = NULL;
     }
 
-  clutter_media_set_filename (media, video_files[count & 1]);
+  clutter_gst_playback_set_filename (player, video_files[count & 1]);
   g_print ("playing %s\n", video_files[count & 1]);
 
   if (uri[count & 1] == NULL)
     {
-      uri[count & 1] = g_strdup (clutter_media_get_uri (media));
+      uri[count & 1] = g_strdup (clutter_gst_playback_get_uri (player));
       g_assert (uri[count & 1] != NULL);
     }
 
   /* See if it's still playing */
-  g_assert (clutter_media_get_playing (media));
+  g_assert (clutter_gst_player_get_playing (CLUTTER_GST_PLAYER (player)));
 
   /* See if it's already change to play correct file */
-  playing_uri = clutter_media_get_uri (media);
+  playing_uri = clutter_gst_playback_get_uri (player);
   g_assert_cmpstr (playing_uri, ==, uri[count & 1]);
 
   if (count ++ > 10)
     {
-      clutter_media_set_playing (media, FALSE);
+      clutter_gst_player_set_playing (CLUTTER_GST_PLAYER (player), FALSE);
       clutter_main_quit ();
       return FALSE;
     }
@@ -124,10 +91,11 @@ test (gpointer data)
 int
 main (int argc, char *argv[])
 {
-  ClutterInitError error;
-  ClutterColor     stage_color = { 0x00, 0x00, 0x00, 0x00 };
-  ClutterActor    *stage = NULL;
-  ClutterActor    *video = NULL;
+  ClutterInitError    error;
+  ClutterColor        stage_color = { 0x00, 0x00, 0x00, 0x00 };
+  ClutterActor       *stage = NULL;
+  ClutterActor       *video = NULL;
+  ClutterGstPlayback *player = NULL;
 
   if (argc < 3)
     {
@@ -144,23 +112,26 @@ main (int argc, char *argv[])
   stage = clutter_stage_new ();
   clutter_actor_set_background_color (stage, &stage_color);
 
-  video = clutter_gst_video_texture_new ();
-  g_assert (CLUTTER_GST_IS_VIDEO_TEXTURE(video));
+  player = clutter_gst_playback_new ();
 
-  g_signal_connect (CLUTTER_TEXTURE(video),
-                    "size-change",
-                    G_CALLBACK(size_change),
-                    stage);
-  g_signal_connect (CLUTTER_TEXTURE(video),
+  video = g_object_new (CLUTTER_TYPE_ACTOR,
+                        "content", g_object_new (CLUTTER_GST_TYPE_ASPECTRATIO,
+                                                 "player", player,
+                                                 NULL),
+                        "width", clutter_actor_get_width (stage),
+                        "height", clutter_actor_get_height (stage),
+                        NULL);
+  clutter_actor_add_child (stage, video);
+
+  g_signal_connect (player,
                     "error",
                     G_CALLBACK(on_error),
-                    stage);
-  g_timeout_add (5000, test, video);
-  clutter_media_set_filename (CLUTTER_MEDIA(video), video_files[0]);
-  clutter_media_set_audio_volume (CLUTTER_MEDIA(video), 0.5);
-  clutter_media_set_playing (CLUTTER_MEDIA(video), TRUE);
+                    video);
+  g_timeout_add (5000, test, player);
+  clutter_gst_playback_set_filename (player, video_files[0]);
+  clutter_gst_player_set_audio_volume (CLUTTER_GST_PLAYER (player), 0.5);
+  clutter_gst_player_set_playing (CLUTTER_GST_PLAYER (player), TRUE);
 
-  clutter_actor_add_child (stage, video);
   clutter_actor_show (stage);
   clutter_main ();
 
